@@ -15,3 +15,9 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
         self, service, dict_args, secret_tool, config_tool
     ):
         "get_findings_excepted"
+
+    @abstractmethod
+    def get_all_findings(
+        self, service, dict_args, secret_tool, config_tool
+    ):
+        "get_report"
